summaryrefslogtreecommitdiff
path: root/tests/swappable_models
diff options
context:
space:
mode:
authorTim Graham <timograham@gmail.com>2013-09-03 11:51:34 -0400
committerTim Graham <timograham@gmail.com>2013-09-03 11:51:34 -0400
commit3db66b1d65c12a94476017cbcc86e72fd842d29e (patch)
treeef333f7ca61a877e129bfd040a510045972d8b3b /tests/swappable_models
parent8f7f8bf6884ada8622bc3696c7465c904164d314 (diff)
downloaddjango-3db66b1d65c12a94476017cbcc86e72fd842d29e.tar.gz
Updated syncdb -> migrate in tests.
Diffstat (limited to 'tests/swappable_models')
-rw-r--r--tests/swappable_models/tests.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/swappable_models/tests.py b/tests/swappable_models/tests.py
index 2e2d544cea..85484615a3 100644
--- a/tests/swappable_models/tests.py
+++ b/tests/swappable_models/tests.py
@@ -38,9 +38,9 @@ class SwappableModelTests(TestCase):
Permission.objects.filter(content_type__app_label='swappable_models').delete()
ContentType.objects.filter(app_label='swappable_models').delete()
# Re-run syncdb. This will re-build the permissions and content types.
new_io = StringIO()
- management.call_command('syncdb', load_initial_data=False, interactive=False, stdout=new_io)
+ management.call_command('migrate', load_initial_data=False, interactive=False, stdout=new_io)
# Check that content types and permissions exist for the swapped model,
# but not for the swappable model.
@@ -38,9 +38,9 @@ class SwappableModelTests(TestCase):
Permission.objects.filter(content_type__app_label='swappable_models').delete()
ContentType.objects.filter(app_label='swappable_models').delete()
- # Re-run syncdb. This will re-build the permissions and content types.
+ # Re-run migrate. This will re-build the permissions and content types.
new_io = StringIO()